@@ -1,7 +1,7 @@
-#!/usr/local/bin/python3.6
+#!/usr/local/bin/python3.7
 # -*- coding: utf-8 -*-
 ###############################################################################
-# $Id: ogrmerge.py 545d0423e15cc28a5aca3a9852fab80b80601162 2018-12-12 11:49:36 +1300 Craig de Stigter $
+# $Id: ogrmerge.py cc9448e548718763514f757da1abdcfdd0a39615 2019-05-21 00:11:23 +0200 Even Rouault $
 #
 # Project:  GDAL/OGR samples
 # Purpose:  Merge the content of several vector datasets into a single one.
@@ -110,7 +110,7 @@ def GetOutputDriverFor(filename):
         else:
             raise Exception("Cannot guess driver for %s" % filename)
     elif len(drv_list) > 1:
-        print("Several drivers matching %s extension. Using %s" % (ext, drv_list[0]))
+        print("Several drivers matching %s extension. Using %s" % (ext if ext else '', drv_list[0]))
     return drv_list[0]
 
 #############################################################################
@@ -453,13 +453,15 @@ def process(argv, progress=None, progress_arg=None):
 
                 writer.open_element('OGRVRTLayer',
                                     attrs={'name': layer_name})
-                attrs = None
+                attrs = {}
                 if EQUAL(output_format, 'VRT') and \
                    os.path.exists(src_dsname) and \
                    not os.path.isabs(src_dsname) and \
                    '/' not in vrt_filename and \
                    '\\' not in vrt_filename:
-                    attrs = {'relativeToVRT': '1'}
+                    attrs['relativeToVRT'] = '1'
+                if single_layer:
+                    attrs['shared'] = '1'
                 writer.write_element_value('SrcDataSource', src_dsname,
                                            attrs=attrs)
                 writer.write_element_value('SrcLayer', src_lyr.GetName())
@@ -550,13 +552,15 @@ def process(argv, progress=None, progress_arg=None):
 
                 writer.open_element('OGRVRTLayer',
                                     attrs={'name': layer_name})
-                attrs = None
+                attrs = {}
                 if EQUAL(output_format, 'VRT') and \
                    os.path.exists(src_dsname) and \
                    not os.path.isabs(src_dsname) and \
                    '/' not in vrt_filename and \
                    '\\' not in vrt_filename:
-                    attrs = {'relativeToVRT': '1'}
+                    attrs['relativeToVRT'] = '1'
+                if single_layer:
+                    attrs['shared'] = '1'
                 writer.write_element_value('SrcDataSource', src_dsname,
                                            attrs=attrs)
                 writer.write_element_value('SrcLayer', src_lyr_name)
