@@ -1,6 +1,6 @@
 #!/usr/local/bin/python3.7
 # ******************************************************************************
-#  $Id: pct2rgb.py 2cd032b5169300975d137226eb99944340ac8c31 2018-05-10 19:33:02 +1000 Ben Elliston $
+#  $Id: pct2rgb.py b26086d4ebbccb1ef862f2eebee8cf79ef17ca66 2019-07-12 07:47:26 -0700 ajnisbet $
 #
 #  Name:     pct2rgb
 #  Project:  GDAL Python Interface
@@ -87,14 +87,14 @@ def GetOutputDriversFor(filename):
 
 def GetOutputDriverFor(filename):
     drv_list = GetOutputDriversFor(filename)
+    ext = GetExtension(filename)
     if not drv_list:
-        ext = GetExtension(filename)
         if not ext:
             return 'GTiff'
         else:
             raise Exception("Cannot guess driver for %s" % filename)
     elif len(drv_list) > 1:
-        print("Several drivers matching %s extension. Using %s" % (ext, drv_list[0]))
+        print("Several drivers matching %s extension. Using %s" % (ext if ext else '', drv_list[0]))
     return drv_list[0]
 
 # =============================================================================
